flutter_france_identite
library
Functions
-
checkCorrespondingInfos(dynamic responseBody, String? name, String? familyName, String? gender, String? nationality, String? birthdate, String? birthplace)
→ bool
-
Checks if the information in the response body matches the provided information.
-
checkDocumentValidity(SharedFile? sharedFile)
→ Future<List>
-
Sends a POST request to the French Identity Provider's document validation API.
-
franceIdentiteLogo({double? width, double? height})
→ Widget
-
Returns a widget displaying the France Identité logo.
-
isFranceIdentiteInstalled({String? androidPackageName, String? iosUrlScheme})
→ Future<bool>
-
Checks if the France Identité app is installed.
-
marianneLogo({double? width, double? height})
→ Widget
-
Returns a widget displaying the Marianne logo.
-
openFranceIdentite({String? androidPackageName, String? iosUrlScheme, String? appStoreLink, bool? openStore})
→ Future<int>
-
Opens the France Identité app.
-
verifyIdentity(SharedFile? sharedFile, String? name, String? familyName, String? gender, String? nationality, String? birthdate, String? birthplace)
→ Future<bool>
-
Verifies the identity of a user by checking the validity of a document and comparing the information in the document with the provided information.